@@ -1,5 +1,4 @@
 #!/usr/bin/env python
-# -*- coding: utf-8 -*-
 
 """PyTorch LightningDataModule for FashionMNIST dataset.
 
@@ -8,15 +7,17 @@ Returns:
     - FashionMNISTDataModule: PyTorch LightningDataModule for FashionMNIST datasets. Supports iid and non-iid splits.
 """
 import enum
-import torch
-import numpy as np
-from pathlib import Path
-import pytorch_lightning as pl
-from typing import Iterable, Tuple, Any, Optional, Dict, List, Set
 import os
-from torch.utils.data import random_split, DataLoader, Dataset
-from torchvision.datasets import FashionMNIST
+from collections.abc import Iterable
+from pathlib import Path
+from typing import Any
+
+import numpy as np
+import pytorch_lightning as pl
+import torch
+from torch.utils.data import DataLoader, Dataset, random_split
 from torchvision import transforms
+from torchvision.datasets import FashionMNIST
 
 torch.manual_seed(42)
 np.random.seed(42)
@@ -58,7 +59,7 @@ class DatasetSplit(Dataset):
             - idxs (List[int]): collection of indices.
         """
         self.dataset: Any = dataset
-        self.idxs: List[int] = list(idxs)
+        self.idxs: list[int] = list(idxs)
         all_targets: np.ndarray = (
             np.array(dataset.targets)
             if isinstance(dataset.targets, list)
@@ -74,7 +75,7 @@ class DatasetSplit(Dataset):
         """
         return len(self.idxs)
 
-    def __getitem__(self, index: int) -> Tuple[Any, Any]:
+    def __getitem__(self, index: int) -> tuple[Any, Any]:
         """Overriding the get method.
 
         Args:
@@ -139,18 +140,23 @@ class FashionMNISTDataModule(pl.LightningDataModule):
         FashionMNIST(self.data_dir, train=True, download=True)
         FashionMNIST(self.data_dir, train=False, download=True)
 
-    def setup(self, stage: Optional[str] = None) -> None:
+    def setup(self, stage: str | None = None) -> None:
         """Setup before training/testing/validation/prediction using the dataset.
 
         Args:
             - stage (Optional[str], optional): Current stage of the PyTorch training process used for setup. Defaults to None.
         """
-        total_images: int = len(FashionMNIST(self.data_dir, train=True, download=True))
+        total_images: int = len(
+            FashionMNIST(self.data_dir, train=True, download=True)
+        )
         num_validation_images: int = int(total_images * self.validation_split)
         num_training_images: int = total_images - num_validation_images
         if (stage == "fit") or (not stage):
             self.fashionmnist_train_full = FashionMNIST(
-                self.data_dir, train=True, download=True, transform=self.train_transform
+                self.data_dir,
+                train=True,
+                download=True,
+                transform=self.train_transform,
             )
             self.fashionmnist_train, self.fashionmnist_val = random_split(
                 self.fashionmnist_train_full,
@@ -159,7 +165,10 @@ class FashionMNISTDataModule(pl.LightningDataModule):
 
         if (stage == "test") or (not stage):
             self.fashionmnist_test = FashionMNIST(
-                self.data_dir, train=False, download=True, transform=self.test_transform
+                self.data_dir,
+                train=False,
+                download=True,
+                transform=self.test_transform,
             )
         if (stage == "predict") or (not stage):
             self.fashionmnist_predict = FashionMNIST(
@@ -219,7 +228,7 @@ class FashionMNISTDataModule(pl.LightningDataModule):
 
     def federated_iid_dataloader(
         self, num_workers: int = 10, workers_batch_size: int = 10
-    ) -> Dict[int, DataLoader]:
+    ) -> dict[int, DataLoader]:
         """Loads the training dataset as iid split among the workers.
 
         Args:
@@ -231,9 +240,11 @@ class FashionMNISTDataModule(pl.LightningDataModule):
         """
         items: int = len(self.fashionmnist_train_full) // num_workers
         distribution: np.ndarray = np.random.randint(
-            low=0, high=len(self.fashionmnist_train_full), size=(num_workers, items)
+            low=0,
+            high=len(self.fashionmnist_train_full),
+            size=(num_workers, items),
         )
-        federated: Dict[int, DataLoader] = dict()
+        federated: dict[int, DataLoader] = {}
         for i in range(len(distribution)):
             federated[i] = DataLoader(
                 DatasetSplit(self.fashionmnist_train_full, distribution[i]),
@@ -244,8 +255,11 @@ class FashionMNISTDataModule(pl.LightningDataModule):
         return federated
 
     def federated_non_iid_dataloader(
-        self, num_workers: int = 10, workers_batch_size: int = 10, niid_factor: int = 2
-    ) -> Dict[int, DataLoader]:
+        self,
+        num_workers: int = 10,
+        workers_batch_size: int = 10,
+        niid_factor: int = 2,
+    ) -> dict[int, DataLoader]:
         """Loads the training dataset as non-iid split among the workers.
 
         Args:
@@ -258,7 +272,7 @@ class FashionMNISTDataModule(pl.LightningDataModule):
         """
         shards: int = num_workers * niid_factor
         items: int = len(self.fashionmnist_train_full) // shards
-        idx_shard: List[int] = list(range(shards))
+        idx_shard: list[int] = list(range(shards))
         classes: np.ndarray = (
             np.array(self.fashionmnist_train_full.targets)
             if isinstance(self.fashionmnist_train_full.targets, list)
@@ -270,22 +284,25 @@ class FashionMNISTDataModule(pl.LightningDataModule):
         )
         idxs_labels = idxs_labels[:, idxs_labels[1, :].argsort()]
         idxs: np.ndarray = idxs_labels[0, :]
-        distribution: Dict[int, np.ndarray] = {
+        distribution: dict[int, np.ndarray] = {
             i: np.array([], dtype="int64") for i in range(num_workers)
         }
         np.random.seed(42)
         while idx_shard:
             for i in range(num_workers):
-                rand_set: Set[int] = set(
+                rand_set: set[int] = set(
                     np.random.choice(idx_shard, niid_factor, replace=False)
                 )
                 idx_shard = list(set(idx_shard) - rand_set)
                 for rand in rand_set:
                     distribution[i] = np.concatenate(
-                        (distribution[i], idxs[rand * items : (rand + 1) * items]),
+                        (
+                            distribution[i],
+                            idxs[rand * items : (rand + 1) * items],
+                        ),
                         axis=0,
                     )
-        federated: Dict[int, DataLoader] = dict()
+        federated: dict[int, DataLoader] = {}
         for i in distribution:
             federated[i] = DataLoader(
                 DatasetSplit(self.fashionmnist_train_full, distribution[i]),
