@@ -1,5 +1,4 @@
 #!/usr/bin/env python
-# -*- coding: utf-8 -*-
 # type: ignore
 
 """Implementation of the pre-trained ResNet architectures using PyTorch and torchvision.
@@ -16,12 +15,14 @@ Contains:
     - WideResNet101_2
 """
 
-from torchvision import models
 from types import SimpleNamespace
+
 import torch.nn as nn
-from torchfl.compatibility import ACTIVATION_FUNCTIONS_BY_NAME
+from torchvision import models
 from torchvision.models.resnet import BasicBlock, Bottleneck
 
+from torchfl.compatibility import ACTIVATION_FUNCTIONS_BY_NAME
+
 
 class ResNet18(models.ResNet):
     """ResNet18 base definition"""
@@ -44,7 +45,7 @@ class ResNet18(models.ResNet):
             - num_channels (int, optional): Number of incoming channels. Defaults to 3.
             - act_fn_name (str, optional): Activation function to be used. Defaults to "relu". Accepted: ["tanh", "relu", "leakyrelu", "gelu"].
         """
-        super(ResNet18, self).__init__(BasicBlock, [2, 2, 2, 2])
+        super().__init__(BasicBlock, [2, 2, 2, 2])
         self.hparams = SimpleNamespace(
             model_name="resnet18",
             pre_trained=pre_trained,
@@ -66,7 +67,12 @@ class ResNet18(models.ResNet):
 
         if num_channels != 3:
             self.conv1 = nn.Conv2d(
-                num_channels, 64, kernel_size=7, stride=2, padding=3, bias=False
+                num_channels,
+                64,
+                kernel_size=7,
+                stride=2,
+                padding=3,
+                bias=False,
             )
 
         in_features = self.fc.in_features
@@ -94,7 +100,7 @@ class ResNet34(models.ResNet):
             - num_channels (int, optional): Number of incoming channels. Defaults to 3.
             - act_fn_name (str, optional): Activation function to be used. Defaults to "relu". Accepted: ["tanh", "relu", "leakyrelu", "gelu"].
         """
-        super(ResNet34, self).__init__(BasicBlock, [3, 4, 6, 3])
+        super().__init__(BasicBlock, [3, 4, 6, 3])
         self.hparams = SimpleNamespace(
             model_name="resnet34",
             pre_trained=pre_trained,
@@ -115,7 +121,12 @@ class ResNet34(models.ResNet):
                     param.requires_grad = False
         if num_channels != 3:
             self.conv1 = nn.Conv2d(
-                num_channels, 64, kernel_size=7, stride=2, padding=3, bias=False
+                num_channels,
+                64,
+                kernel_size=7,
+                stride=2,
+                padding=3,
+                bias=False,
             )
 
         in_features = self.fc.in_features
@@ -143,7 +154,7 @@ class ResNet50(models.ResNet):
             - num_channels (int, optional): Number of incoming channels. Defaults to 3.
             - act_fn_name (str, optional): Activation function to be used. Defaults to "relu". Accepted: ["tanh", "relu", "leakyrelu", "gelu"].
         """
-        super(ResNet50, self).__init__(Bottleneck, [3, 4, 6, 3])
+        super().__init__(Bottleneck, [3, 4, 6, 3])
         self.hparams = SimpleNamespace(
             model_name="resnet50",
             pre_trained=pre_trained,
@@ -164,7 +175,12 @@ class ResNet50(models.ResNet):
                     param.requires_grad = False
         if num_channels != 3:
             self.conv1 = nn.Conv2d(
-                num_channels, 64, kernel_size=7, stride=2, padding=3, bias=False
+                num_channels,
+                64,
+                kernel_size=7,
+                stride=2,
+                padding=3,
+                bias=False,
             )
 
         in_features = self.fc.in_features
@@ -192,7 +208,7 @@ class ResNet101(models.ResNet):
             - num_channels (int, optional): Number of incoming channels. Defaults to 3.
             - act_fn_name (str, optional): Activation function to be used. Defaults to "relu". Accepted: ["tanh", "relu", "leakyrelu", "gelu"].
         """
-        super(ResNet101, self).__init__(Bottleneck, [3, 4, 23, 3])
+        super().__init__(Bottleneck, [3, 4, 23, 3])
         self.hparams = SimpleNamespace(
             model_name="resnet101",
             pre_trained=pre_trained,
@@ -213,7 +229,12 @@ class ResNet101(models.ResNet):
                     param.requires_grad = False
         if num_channels != 3:
             self.conv1 = nn.Conv2d(
-                num_channels, 64, kernel_size=7, stride=2, padding=3, bias=False
+                num_channels,
+                64,
+                kernel_size=7,
+                stride=2,
+                padding=3,
+                bias=False,
             )
 
         in_features = self.fc.in_features
@@ -241,7 +262,7 @@ class ResNet152(models.ResNet):
             - num_channels (int, optional): Number of incoming channels. Defaults to 3.
             - act_fn_name (str, optional): Activation function to be used. Defaults to "relu". Accepted: ["tanh", "relu", "leakyrelu", "gelu"].
         """
-        super(ResNet152, self).__init__(Bottleneck, [3, 8, 36, 3])
+        super().__init__(Bottleneck, [3, 8, 36, 3])
         self.hparams = SimpleNamespace(
             model_name="resnet152",
             pre_trained=pre_trained,
@@ -262,7 +283,12 @@ class ResNet152(models.ResNet):
                     param.requires_grad = False
         if num_channels != 3:
             self.conv1 = nn.Conv2d(
-                num_channels, 64, kernel_size=7, stride=2, padding=3, bias=False
+                num_channels,
+                64,
+                kernel_size=7,
+                stride=2,
+                padding=3,
+                bias=False,
             )
 
         in_features = self.fc.in_features
@@ -290,7 +316,7 @@ class ResNext50_32X4D(models.ResNet):
             - num_channels (int, optional): Number of incoming channels. Defaults to 3.
             - act_fn_name (str, optional): Activation function to be used. Defaults to "relu". Accepted: ["tanh", "relu", "leakyrelu", "gelu"].
         """
-        super(ResNext50_32X4D, self).__init__(
+        super().__init__(
             block=Bottleneck, layers=[3, 4, 6, 3], groups=32, width_per_group=4
         )
         self.hparams = SimpleNamespace(
@@ -306,14 +332,21 @@ class ResNext50_32X4D(models.ResNet):
         )
 
         if pre_trained:
-            pretrained_model = models.resnext50_32x4d(pretrained=True, progress=True)
+            pretrained_model = models.resnext50_32x4d(
+                pretrained=True, progress=True
+            )
             self.load_state_dict(pretrained_model.state_dict())
             if feature_extract:
                 for param in self.parameters():
                     param.requires_grad = False
         if num_channels != 3:
             self.conv1 = nn.Conv2d(
-                num_channels, 64, kernel_size=7, stride=2, padding=3, bias=False
+                num_channels,
+                64,
+                kernel_size=7,
+                stride=2,
+                padding=3,
+                bias=False,
             )
 
         in_features = self.fc.in_features
@@ -341,8 +374,11 @@ class ResNext101_32X8D(models.ResNet):
             - num_channels (int, optional): Number of incoming channels. Defaults to 3.
             - act_fn_name (str, optional): Activation function to be used. Defaults to "relu". Accepted: ["tanh", "relu", "leakyrelu", "gelu"].
         """
-        super(ResNext101_32X8D, self).__init__(
-            block=Bottleneck, layers=[3, 4, 23, 3], groups=32, width_per_group=8
+        super().__init__(
+            block=Bottleneck,
+            layers=[3, 4, 23, 3],
+            groups=32,
+            width_per_group=8,
         )
         self.hparams = SimpleNamespace(
             model_name="resnext101_32x8d",
@@ -357,14 +393,21 @@ class ResNext101_32X8D(models.ResNet):
         )
 
         if pre_trained:
-            pretrained_model = models.resnext101_32x8d(pretrained=True, progress=True)
+            pretrained_model = models.resnext101_32x8d(
+                pretrained=True, progress=True
+            )
             self.load_state_dict(pretrained_model.state_dict())
             if feature_extract:
                 for param in self.parameters():
                     param.requires_grad = False
         if num_channels != 3:
             self.conv1 = nn.Conv2d(
-                num_channels, 64, kernel_size=7, stride=2, padding=3, bias=False
+                num_channels,
+                64,
+                kernel_size=7,
+                stride=2,
+                padding=3,
+                bias=False,
             )
 
         in_features = self.fc.in_features
@@ -392,7 +435,7 @@ class WideResNet50_2(models.ResNet):
             - num_channels (int, optional): Number of incoming channels. Defaults to 3.
             - act_fn_name (str, optional): Activation function to be used. Defaults to "relu". Accepted: ["tanh", "relu", "leakyrelu", "gelu"].
         """
-        super(WideResNet50_2, self).__init__(
+        super().__init__(
             block=Bottleneck, layers=[3, 4, 6, 3], width_per_group=128
         )
         self.hparams = SimpleNamespace(
@@ -408,14 +451,21 @@ class WideResNet50_2(models.ResNet):
         )
 
         if pre_trained:
-            pretrained_model = models.wide_resnet50_2(pretrained=True, progress=True)
+            pretrained_model = models.wide_resnet50_2(
+                pretrained=True, progress=True
+            )
             self.load_state_dict(pretrained_model.state_dict())
             if feature_extract:
                 for param in self.parameters():
                     param.requires_grad = False
         if num_channels != 3:
             self.conv1 = nn.Conv2d(
-                num_channels, 64, kernel_size=7, stride=2, padding=3, bias=False
+                num_channels,
+                64,
+                kernel_size=7,
+                stride=2,
+                padding=3,
+                bias=False,
             )
 
         in_features = self.fc.in_features
@@ -443,7 +493,7 @@ class WideResNet101_2(models.ResNet):
             - num_channels (int, optional): Number of incoming channels. Defaults to 3.
             - act_fn_name (str, optional): Activation function to be used. Defaults to "relu". Accepted: ["tanh", "relu", "leakyrelu", "gelu"].
         """
-        super(WideResNet101_2, self).__init__(
+        super().__init__(
             block=Bottleneck, layers=[3, 4, 23, 3], width_per_group=128
         )
         self.hparams = SimpleNamespace(
@@ -459,14 +509,21 @@ class WideResNet101_2(models.ResNet):
         )
 
         if pre_trained:
-            pretrained_model = models.wide_resnet101_2(pretrained=True, progress=True)
+            pretrained_model = models.wide_resnet101_2(
+                pretrained=True, progress=True
+            )
             self.load_state_dict(pretrained_model.state_dict())
             if feature_extract:
                 for param in self.parameters():
                     param.requires_grad = False
         if num_channels != 3:
             self.conv1 = nn.Conv2d(
-                num_channels, 64, kernel_size=7, stride=2, padding=3, bias=False
+                num_channels,
+                64,
+                kernel_size=7,
+                stride=2,
+                padding=3,
+                bias=False,
             )
 
         in_features = self.fc.in_features
